@@ -4,7 +4,7 @@ require 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '2.95';
+our $VERSION = '2.96';
 use Carp;
 use Symbol 'gensym', 'qualify_to_ref';    # For the 'any data type' hack
 use Fcntl qw( SEEK_SET SEEK_CUR );
@@ -1953,12 +1953,16 @@ sub FETCH
     my $self = shift;
     my ($key) = @_;
 
+    $self->{_section_cache} ||= {};
+
     $self->_caseify( \$key );
     return if ( !$self->{v}{$key} );
 
+    return $self->{_section_cache}->{$key} if exists $self->{_section_cache}->{$key};
+
     my %retval;
     tie %retval, 'Config::IniFiles::_section', $self, $key;
-    return \%retval;
+    return $self->{_section_cache}->{$key} = \%retval;
 
 }    # end FETCH
 
@@ -2352,7 +2356,7 @@ Config::IniFiles - A module for reading .ini-style configuration files.
 
 =head1 VERSION
 
-version 2.95
+version 2.96
 
 =head1 SYNOPSIS
 
